@@ -17,13 +17,13 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2018 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2019 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    https://www.imagemagick.org/script/license.php                           %
+%    https://imagemagick.org/script/license.php                               %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -673,7 +673,20 @@ static MagickBooleanType WritePCLImage(const ImageInfo *image_info,Image *image)
   register const IndexPacket
     *indexes;
 
-  register const PixelPacket *p; register ssize_t i, x; register unsigned char *q; size_t density, length,
+  register const PixelPacket
+    *p;
+
+  register ssize_t
+    i,
+    x;
+
+  register unsigned char
+    *q;
+
+  size_t
+    density,
+    imageListLength,
+    length,
     one,
     packets;
 
@@ -709,6 +722,7 @@ static MagickBooleanType WritePCLImage(const ImageInfo *image_info,Image *image)
     }
   scene=0;
   one=1;
+  imageListLength=GetImageListLength(image);
   do
   {
     /*
@@ -966,8 +980,7 @@ static MagickBooleanType WritePCLImage(const ImageInfo *image_info,Image *image)
     if (GetNextImageInList(image) == (Image *) NULL)
       break;
     image=SyncNextImageInList(image);
-    status=SetImageProgress(image,SaveImagesTag,scene++,
-      GetImageListLength(image));
+    status=SetImageProgress(image,SaveImagesTag,scene++,imageListLength);
     if (status == MagickFalse)
       break;
   } while (image_info->adjoin != MagickFalse);
